@@ -30,6 +30,9 @@ for filename in args:
             if block[n].endswith("=\r"):
                 out_vcard.append(block[n][:-2] + block[n+1])
                 n = n + 1
+            elif block[n].endswith("="):
+                out_vcard.append(block[n][:-1] + block[n+1])
+                n = n + 1
             else:
                 out_vcard.append(block[n])
             n = n + 1
