@@ -207,11 +207,10 @@ int plugin_startup(jp_startup_info *info)
   jp_init();
   jp_logf(JP_LOG_INFO, "jppy: Starting...\n");
 
-  // we seem to have to do this, as well as just linking this plugin
-  // to the python library, otherwise init_pygobject() causes the
-  // plugin to stop-and-exit. If we only do this and don't link,
-  // then we get  
-  // error [/usr/lib/jpilot/plugins/libjppy.so: undefined symbol: PyExc_ImportError]
+  // This is because python modules don't -lpython, combined with
+  // jpilot not loading the plugins with RTLD_GLOBAL, so the plugin's
+  // -lpython isn't then available to the python modules that it
+  // uses... See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=491848
   if (!dlopen (PYTHON_SHARED_LIB, RTLD_NOW | RTLD_GLOBAL)) { 
     jp_logf(JP_LOG_FATAL, "\n%s\n", dlerror()); 
     python_is_working = 0; 
@@ -231,7 +230,12 @@ int plugin_startup(jp_startup_info *info)
 
   jp_logf(JP_LOG_DEBUG, "jppy: Imported os, sys\n");
 
-  init_pygobject();
+  PyObject *gobject = pygobject_init(2,4,0);
+  if (gobject == NULL) {
+    PyErr_Print();
+    return 0;
+  }
+
   jp_logf(JP_LOG_DEBUG, "jppy: Initialized pygobject\n");
 
   PyRun_SimpleString("sys.path.insert(0,'%s/.jpilot/python' % (os.getenv('JPILOT_HOME') or os.getenv('HOME')))");
