@@ -16,16 +16,12 @@ import popen2
 from gtk_models import ContactsModel
 
 try:
-    from Asterisk.Manager import Manager
-    AsteriskManager = Manager
-    del Manager
+    from Asterisk.Manager import Manager as AsteriskManager
 except:
     AsteriskManager = None
 
 try:
-    from clickatell.http import sms
-    SMSManager = sms
-    del sms
+    from clickatell.http import sms as SMSManager
 except:
     SMSManager = None
 
@@ -55,6 +51,13 @@ class pane(base.pane):
 
         wTree.get_widget("contactsDialButton").set_sensitive(AsteriskManager != None)
 
+        try:
+            mode = jppy.config.get("sms","mode")
+        except (ConfigParser.NoSectionError, ConfigParser.NoOptionError), e:
+            mode = None
+        if mode == "clickatell" and SMSManager == None:
+            wTree.get_widget("contactsSMSButton").set_sensitive(False)
+
         cb = wTree.get_widget("birthdayCheckbox")
         w  = wTree.get_widget("birthdayDateEdit")
         self.joinValidCheckboxToWidget(cb, w, self.on_dateedit_change)
@@ -337,7 +340,7 @@ class pane(base.pane):
     def fetchSMSConfig(self):
         try:
             mode = jppy.config.get("sms","mode")
-        except ConfigParser.NoOptionError, e:            
+        except (ConfigParser.NoSectionError, ConfigParser.NoOptionError), e:
             d = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
                                   "Error with ~/.jppyrc: No [sms]/mode set")
             d.run()
