@@ -415,11 +415,21 @@ static PyObject* PyPiContact_Generate_VCard(PyPiContact* self, PyObject *args, P
     }  else if (self->a.entry[contLastname]) {
       safeAddPropValue(vcard,VCFullNameProp,self->a.entry[contLastname]);
     }
+  } else {
+    // VCNameProp is mandatory (see vCard 2.1 spec 2.2.2) so try hard to write one
+    prop = addProp(vcard,VCNameProp);
+    if ((self->a.entry[contCompany]) && (strcmp("",self->a.entry[contCompany]))) {
+      safeAddPropValue(prop,VCFamilyNameProp,self->a.entry[contCompany]);
+    } else {
+      snprintf(strbuf, 254, "palm-contact-%d", self->unique_id);
+      safeAddPropValue(prop,VCFamilyNameProp,strbuf);
+    }
   }
   
   if (self->a.entry[contCompany] && strcmp("",self->a.entry[contCompany])) {
     prop = addProp(vcard,VCOrgProp);
     safeAddPropValue(prop,VCOrgNameProp,self->a.entry[contCompany]);
+    safeAddPropValue(prop,VCOrgUnitProp,"");
   }
 
   safeAddPropValue(vcard,VCTitleProp,self->a.entry[contTitle]);
