@@ -214,11 +214,43 @@ static PyObject* PyPiEvent_items(PyObject* self) {
   return list;
 }
 
+static PyObject* PyPiEvent_Generate_ical(PyPiEvent *self) {
+  PyObject *pyicalmod, *pyicaldict, *pyicalstr, *pyicalfunction, *pyvevent;
+
+  pyicalstr = PyString_FromString("jppy.ical");
+  pyicalmod = PyImport_Import(pyicalstr);    
+  Py_DECREF(pyicalstr);
+  if (pyicalmod == NULL) {
+    return NULL;
+  }  
+  pyicaldict = PyModule_GetDict(pyicalmod); // borrowed
+  Py_DECREF(pyicalmod);
+  if (pyicaldict == NULL) {
+    return NULL;
+  }
+  Py_INCREF(pyicaldict);
+  pyicalfunction = PyDict_GetItemString(pyicaldict, "event_to_vevent"); // borrowed
+  Py_DECREF(pyicaldict);
+  if (pyicalfunction == NULL) {
+    return NULL;
+  }
+  Py_INCREF(pyicalfunction);
+  Py_INCREF(self);
+  pyvevent = PyObject_CallFunction(pyicalfunction,"(O)",(PyObject *)self);
+  Py_DECREF(self);
+  Py_DECREF(pyicalfunction);
+  if (pyvevent == NULL) {
+    return NULL;
+  }
+  return pyvevent;
+}
+
 /*******************************************************
  * 
  ******************************************************/
 
 static PyMethodDef PyPiEvent_Methods[] = {
+  { "ical", (PyCFunction)PyPiEvent_Generate_ical, METH_NOARGS, "Return vevent object"},
   { "keys", (PyCFunction)PyPiEvent_keys, METH_NOARGS, "Return a list of available keys"},
   { "items",(PyCFunction)PyPiEvent_items, METH_NOARGS, "Return a list of available items"},
   { "values",(PyCFunction)PyPiEvent_values, METH_NOARGS, "Return a list of available items"},
@@ -258,7 +290,7 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
     PyObject *rruleset, *rrule;
     PyObject *function, *result;
     PyObject *basicRepeat;
-    PyObject *skipDate;
+    PyObject *skipDate, *skipDatetz;
     PyObject *args, *kwargs;
     PyObject *interval;
     int i;
@@ -299,24 +331,34 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
       PyObject *weekdayConstantWithWeek;
       int week;
     case repeatNone:
-      // printf("has no repeat, so almost empty rruleset\n");
+      //printf("has no repeat, so almost empty rruleset\n");
       Py_DECREF(dateutil_rrule_dict);
       {
-	PyObject *dtstart;
-	dtstart = PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
-					     self->a.begin.tm_mon + 1,
-					     self->a.begin.tm_mday,
-					     self->a.begin.tm_hour,
-					     self->a.begin.tm_min,
-					     self->a.begin.tm_sec,
-					     0);
-	PyDict_SetItemString(kwargs,"dtstart",dtstart);
-	result = PyObject_CallMethod(rruleset,"rdate","(O)",dtstart);
-	if (result == NULL) {
+	PyObject *dtstart, *dtstarttz;
+	if (self->a.event) {
+	  // don't TZ-aware, for icalendar.py:459 doesn't expect it to be
+	  dtstarttz =  PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
+						  self->a.begin.tm_mon + 1,
+						  self->a.begin.tm_mday,
+						  0,0,0,0);
+	} else {
+	  dtstart = PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
+					       self->a.begin.tm_mon + 1,
+					       self->a.begin.tm_mday,
+					       self->a.begin.tm_hour,
+					       self->a.begin.tm_min,
+					       self->a.begin.tm_sec,
+					       0);
+	  dtstarttz = DateTimeLocalize(dtstart);
 	  Py_DECREF(dtstart);
+	}
+	PyDict_SetItemString(kwargs,"dtstart",dtstarttz);
+	result = PyObject_CallMethod(rruleset,"rdate","(O)",dtstarttz);
+	if (result == NULL) {
+	  Py_DECREF(dtstarttz);
 	  return NULL;
 	}
-	Py_DECREF(dtstart);
+	Py_DECREF(dtstarttz);
       }
       return rruleset;
       break;
@@ -334,7 +376,8 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
 	if(self->a.repeatDays[i]) {
 	  //printf("repeatDays[%d] is true\n", i);
 	  m = i-1;
-	  if (m < 0) {m = 7;}
+	  if (m < 0) {m = 6;}
+	  //printf("giving weekday %d\n", m);
 	  PyList_Append(repeatList, Py_BuildValue("i",m));
 	}
       }
@@ -398,7 +441,7 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
     PyDict_SetItemString(kwargs,"interval",interval);
     Py_DECREF(interval);
     {
-      PyObject *dtstart;
+      PyObject *dtstart, *dtstarttz;
       dtstart = PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
 					   self->a.begin.tm_mon + 1,
 					   self->a.begin.tm_mday,
@@ -406,16 +449,21 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
 					   self->a.begin.tm_min,
 					   self->a.begin.tm_sec,
 					   0);
-      PyDict_SetItemString(kwargs,"dtstart",dtstart);
+      dtstarttz = DateTimeLocalize(dtstart);
       Py_DECREF(dtstart);
+      PyDict_SetItemString(kwargs,"dtstart",dtstarttz);
+      Py_DECREF(dtstarttz);
     }
     if (!(self->a.repeatForever)) {
-      PyObject *untildatetime;
-      untildatetime = PyDate_FromDate(self->a.repeatEnd.tm_year + 1900,
-				      self->a.repeatEnd.tm_mon + 1,
-				      self->a.repeatEnd.tm_mday);
-      PyDict_SetItemString(kwargs,"until",untildatetime);
+      PyObject *untildatetime, *untildatetimetz;
+      untildatetime = PyDateTime_FromDateAndTime(self->a.repeatEnd.tm_year + 1900,
+						 self->a.repeatEnd.tm_mon + 1,
+						 self->a.repeatEnd.tm_mday,
+						 0,0,0,0);
+      untildatetimetz = DateTimeLocalize(untildatetime);
       Py_DECREF(untildatetime);
+      PyDict_SetItemString(kwargs,"until",untildatetimetz);
+      Py_DECREF(untildatetimetz);
     }
     {
       PyObject *wkst;
@@ -455,13 +503,15 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
 					    self->a.exception[i].tm_mon + 1,
 					    self->a.exception[i].tm_mday,
 					    0,0,0,0);
-      result = PyObject_CallMethod(rruleset,"exdate","(O)",skipDate);
+      skipDatetz = DateTimeLocalize(skipDate);
+      Py_DECREF(skipDate);      
+      result = PyObject_CallMethod(rruleset,"exdate","(O)",skipDatetz);
       if (result == NULL) {
-	Py_DECREF(skipDate);
+	Py_DECREF(skipDatetz);
 	return NULL;
       }
       Py_DECREF(result);
-      Py_DECREF(skipDate);
+      Py_DECREF(skipDatetz);
     }
     return rruleset;
   }
@@ -503,13 +553,17 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
 			     self->a.begin.tm_mon + 1,
 			     self->a.begin.tm_mday);
     } else {
-      return PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
-					self->a.begin.tm_mon + 1,
-					self->a.begin.tm_mday,
-					self->a.begin.tm_hour,
-					self->a.begin.tm_min,
-					self->a.begin.tm_sec,
-					0);
+      PyObject *pydatetime, *pydatetimetz;
+      pydatetime = PyDateTime_FromDateAndTime(self->a.begin.tm_year + 1900,
+					      self->a.begin.tm_mon + 1,
+					      self->a.begin.tm_mday,
+					      self->a.begin.tm_hour,
+					      self->a.begin.tm_min,
+					      self->a.begin.tm_sec,
+					      0);
+      pydatetimetz =  DateTimeLocalize(pydatetime);
+      Py_DECREF(pydatetime);
+      return pydatetimetz;
     }
   }
   if (strcasecmp(keystring,"end") == 0) {
@@ -519,13 +573,17 @@ PyObject *PyPiEvent_GetItem(PyPiEvent* self,  PyObject* key) {
 			     self->a.end.tm_mon + 1,
 			     self->a.end.tm_mday);
     } else {
-      return PyDateTime_FromDateAndTime(self->a.end.tm_year + 1900,
-					self->a.end.tm_mon + 1,
-					self->a.end.tm_mday,
-					self->a.end.tm_hour,
-					self->a.end.tm_min,
-					self->a.end.tm_sec,
-					0);
+      PyObject *pydatetime, *pydatetimetz;
+      pydatetime = PyDateTime_FromDateAndTime(self->a.end.tm_year + 1900,
+					      self->a.end.tm_mon + 1,
+					      self->a.end.tm_mday,
+					      self->a.end.tm_hour,
+					      self->a.end.tm_min,
+					      self->a.end.tm_sec,
+					      0);
+      pydatetimetz =  DateTimeLocalize(pydatetime);
+      Py_DECREF(pydatetime);
+      return pydatetimetz;
     }
   }
 
@@ -578,7 +636,50 @@ static PyMappingMethods PyPiEvent_Mapping = {
   (objobjargproc)PyPiEvent_SetItem,
 };
 
+PyObject *DateTimeLocalize(PyObject *pydatetime) {
+  PyObject *pydatetimetz;
+  PyObject *pytz_mod, *pytz_dict, *pystr, *pyfunction, *tz;
 
+  if (pydatetime == NULL) return NULL;
+  Py_INCREF(pydatetime);
+  pystr = PyString_FromString("pytz");
+  pytz_mod = PyImport_Import(pystr);
+  Py_DECREF(pystr);
+  if (pytz_mod == NULL) {
+    Py_DECREF(pydatetime);
+    return NULL;
+  }
+  pytz_dict = PyModule_GetDict(pytz_mod); // borrowed
+  Py_DECREF(pytz_mod);
+  if (pytz_dict == NULL) {
+    Py_DECREF(pydatetime);
+    return NULL;
+  }
+  Py_INCREF(pytz_dict);
+  pyfunction = PyDict_GetItemString(pytz_dict, "timezone"); // borrowed
+  Py_DECREF(pytz_dict);
+  if (pyfunction == NULL) {
+    Py_DECREF(pydatetime);
+    return NULL;
+  }
+  Py_INCREF(pyfunction);
+  tz = PyObject_CallFunction(pyfunction,"(s)","Europe/London");
+  Py_DECREF(pyfunction);
+  pyfunction = PyObject_GetAttrString(tz, "localize"); // borrowed
+  Py_DECREF(tz);
+  if (pyfunction == NULL) {
+    Py_DECREF(pydatetime);
+    return NULL;
+  }
+  Py_INCREF(pyfunction);
+  pydatetimetz = PyObject_CallFunction(pyfunction,"(O)",pydatetime);
+  Py_DECREF(pydatetime);
+  Py_DECREF(pyfunction);
+  if (pydatetimetz == NULL) {
+    return NULL;
+  }
+  return pydatetimetz;
+}
 
 /*******************************************************
  * Provide a repr method
