@@ -16,6 +16,12 @@ class contactTest(baseclass.baseTest):
         assert type(self.book.getIMLabels()) == types.ListType
         assert type(self.book.getPhoneLabels()) == types.ListType
 
+    def testVCard(self):
+        c = jppy.Contact()
+        c["address1"] = "Flat 4\nSomewhere Street\nMore Street"
+        c["note"]     = "This is a\nmultiline\nnote"
+        assert "4=0D=0AS" in c.vcard()
+
 def suite():
     suite = unittest.TestSuite((unittest.makeSuite(contactTest),))
     
